--- kirkwood-silverstore-hncn2.dts	2018-11-18 22:32:37.164590285 +0000
+++ patch/kirkwood-silverstore-hncn2.dts	2018-11-18 22:44:33.874236594 +0000
@@ -13,11 +13,11 @@
 
 / {
 	model = "Freecom Silverstore HNCN2";
-	compatible = "freecom,silverstore-hncn2", "marvell,kirkwood-88f6282", "marvell,kirkwood";
+	compatible = "freecom,silverstore-hncn2", "marvell,kirkwood-88f6283", "marvell,kirkwood";
 
 	memory {
 		device_type = "memory";
-		reg = <0x00000000 0x20000000>;
+		reg = <0x00000000 0x08000000>; /* 128 MB DDR3 Samsung (K4B1G1646G-BCH9) */
 	};
 
 	chosen {
@@ -30,27 +30,53 @@
 			pinctrl-names = "default";
 
 			/* Note: need more Silverstore HNCN2 GPIOs */
+            /* SATA activity pins */
+                pmx_sata0: pmx-sata0 {
+                        marvell,pins = "mpp15";
+                        marvell,function = "sata0";
+                };
+                pmx_sata1: pmx-sata1 {
+                        marvell,pins = "mpp16";
+                        marvell,function = "sata1";
+                };
 
+            /* Button Inputs */            
 			pmx_btn_reset: pmx-btn-reset {
 				marvell,pins = "mpp29";
-				marvell,function = "gpio";
+				marvell,function = "sysrst";
 			};
 
 			pmx_pwr_off: pmx-pwr-off {
 				marvell,pins = "mpp36";
 				marvell,function = "gpio";
 			};
+            
+            /* Status LED (red/white) */
+                pmx_led_status_red: pmx-led-status-red {
+                        marvell,pins = "mpp37";
+                        marvell,function = "gpio";
+                };
 
-			pmx_led_sys_green: pmx-led-sys-green {
+            /* Status LED (red/white) */
+			pmx_led_sys_white: pmx-led-sys-white {
 				marvell,pins = "mpp38";
 				marvell,function = "gpio";
 			};
 
-			pmx_led_power_green: pmx-led-power-green {
+            /* Status LED (red/white) */
+			pmx_led_power_white: pmx-led-power-white {
 				marvell,pins = "mpp39";
 				marvell,function = "gpio";
 			};
-
+            
+            /* Status LED (red/white) */
+                pmx_pwr_sata1: pmx-pwr-sata1 {
+                        marvell,pins = "mpp47";
+                        marvell,function = "gpio";            
+
+                };
+            
+            /* Button Inputs */             
 			pmx_btn_power: pmx-btn-power {
 				marvell,pins = "mpp49";
 				marvell,function = "gpio";
@@ -77,7 +103,31 @@
 		};
 	};
 
-
+        regulators {
+                compatible = "simple-bus";
+                #address-cells = <1>;
+                #size-cells = <0>;
+                pinctrl-0 = <&pmx_pwr_sata1>;
+                pinctrl-names = "default";
+
+                usb0_power: regulator@1 {
+                        enable-active-high;
+                };
+
+                /* HDD2 SATA Power is switchable */
+                sata1_power: regulator@2 {
+                        compatible = "regulator-fixed";
+                        reg = <2>;
+                        regulator-name = "SATA1 Power";
+                        regulator-min-microvolt = <5000000>;
+                        regulator-max-microvolt = <5000000>;
+                        regulator-always-on;
+                        regulator-boot-on;
+                        enable-active-high;
+                        gpio = <&gpio1 15 GPIO_ACTIVE_HIGH>;
+                };
+        };
+        
 	gpio_keys {
 		compatible = "gpio-keys";
 		#address-cells = <1>;
@@ -98,24 +148,33 @@
 		};
 	};
 
+   
 	gpio-leds {
 		compatible = "gpio-leds";
-		pinctrl-0 = <&pmx_led_sys_green &pmx_led_power_green>;
+		pinctrl-0 = <&pmx_led_status_red &pmx_led_sys_white &pmx_led_power_white>;
 		pinctrl-names = "default";
 
-		green-sys {
-			label = "hncn2:green:sys";
+            red-led-status {
+                label = "hncn2:red:status";
+                gpios = <&gpio1 5 GPIO_ACTIVE_HIGH>;
+                linux,default-trigger = "heartbeat";
+                default-state = "off";
+            };
+
+		white-sys {
+			label = "hncn2:white:sys";
 			gpios = <&gpio1 6 GPIO_ACTIVE_HIGH>;
 			linux,default-trigger = "default-on";
 		};
 
-		green-power {
-			label = "hncn2:green:power";
+		white-power {
+			label = "hncn2:white:power";
 			gpios = <&gpio1 7 GPIO_ACTIVE_HIGH>;
 		};
 
 	};
 
+    
 	gpio_poweroff {
 		compatible = "gpio-poweroff";
 		pinctrl-0 = <&pmx_pwr_off>;
@@ -127,54 +186,40 @@
 
 &nand {
 	status = "okay";
+    pinctrl-0 = <&pmx_nand>;
+    pinctrl-names = "default";
 	chip-delay = <35>;
 
-	/* Note: need Silverstore mtdparts */
-
-	partition@0 {
-		label = "uboot";
-		reg = <0x0000000 0x0100000>;
-	};
-
-	partition@100000 {
-		label = "uboot_env";
-		reg = <0x0100000 0x0080000>;
-	};
-
-	partition@180000 {
-		label = "key_store";
-		reg = <0x0180000 0x0080000>;
-	};
-
-	partition@200000 {
-		label = "info";
-		reg = <0x0200000 0x0080000>;
-	};
-
-	partition@280000 {
-		label = "etc";
-		reg = <0x0280000 0x0a00000>;
-	};
-
-	partition@c80000 {
-		label = "kernel_1";
-		reg = <0x0c80000 0x0a00000>;
-	};
-
-	partition@1680000 {
-		label = "rootfs1";
-		reg = <0x1680000 0x2fc0000>;
-	};
-
-	partition@4640000 {
-		label = "kernel_2";
-		reg = <0x4640000 0x0a00000>;
-	};
-
-	partition@5040000 {
-		label = "rootfs2";
-		reg = <0x5040000 0x2fc0000>;
-	};
+    
+        partition@0 {
+                label = "uboot";
+                reg = <0x0 0xa0000>;
+        };
+
+        partition@a0000 {
+                label = "env";
+                reg = <0xa0000 0x40000>;
+        };
+
+        partition@e0000 {
+                label = "preroot";
+                reg = <0xe0000 0x280000>;
+        };
+
+        partition@360000 {
+                label = "uImage";
+                reg = <0x360000 0x380000>;
+        };
+
+        partition@6e0000 {
+                label = "rootfs";
+                reg = <0x6e0000 0x76e0000>;
+        };
+
+        partition@7dc0000 {
+                label = "misc";
+                reg = <0x7dc0000 0x240000>;
+        };
 };
 
 &mdio {
@@ -190,9 +235,13 @@
 
 	ethernet0-port@0 {
 		phy-handle = <&ethphy0>;
+        
+                /* overwrite MAC address in bootloader */
+                local-mac-address = your_mac_address;
 	};
 };
 
+/* NEC uPD720200 USB3.0 controller on pcie bus */
 &pciec {
 	status = "okay";
 };
